PlotCurveItem — pyqtgraph 0.11.0rc0 documentation

# PlotCurveItem

class `pyqtgraph.` `PlotCurveItem`(*args, **kargs)

  Class representing a single plot curve. Instances of this class are created automatically as part of PlotDataItem; these rarely need to be instantiated directly.

  Features:

  - Fast data update

  - Fill under curve

  - Mouse interaction

  Signals: |
  sigPlotChanged(self) | Emitted when the data being plotted has changed
  sigClicked(self) | Emitted when the curve is clicked

  `__init__`(*args, **kargs)

    Forwards all arguments to `setData`.

    Some extra arguments are accepted as well:

    Arguments: |
    parent | The parent GraphicsObject (optional)
    clickable | If True, the item will emit sigClicked when it is clicked on. Defaults to False.

  `boundingRect`(self) → PySide2.QtCore.QRectF
  `mouseShape`()

    Return a QPainterPath representing the clickable shape of the curve

  `setBrush`(*args, **kargs)

    Set the brush used when filling the area under the curve

  `setClickable`(s, width=None)

    Sets whether the item responds to mouse clicks.

    The width argument specifies the width in pixels orthogonal to the curve that will respond to a mouse click.

  `setCompositionMode`(mode)

    Change the composition mode of the item (see QPainter::CompositionMode in the Qt documentation). This is useful when overlaying multiple items.

    Most common arguments: |
    QtGui.QPainter.CompositionMode_SourceOver | Default; image replaces the background if it is opaque. Otherwise, it uses the alpha channel to blend the image with the background.
    QtGui.QPainter.CompositionMode_Overlay | The image color is mixed with the background color to reflect the lightness or darkness of the background.
    QtGui.QPainter.CompositionMode_Plus | Both the alpha and color of the image and background pixels are added together.
    QtGui.QPainter.CompositionMode_Multiply | The output is the image color multiplied by the background.

  `setData`(*args, **kargs)

    Arguments: |
    x, y | (numpy arrays) Data to show
    pen | Pen to use when drawing. Any single argument accepted by `mkPen` is allowed.
    shadowPen | Pen for drawing behind the primary pen. Usually this is used to emphasize the curve by providing a high-contrast border. Any single argument accepted by `mkPen` is allowed.
    fillLevel | (float or None) Fill the area ‘under’ the curve to fillLevel
    fillOutline | (bool) If True, an outline surrounding the fillLevel area is drawn.
    brush | QBrush to use when filling. Any single argument accepted by `mkBrush` is allowed.
    antialias | (bool) Whether to use antialiasing when drawing. This is disabled by default because it decreases performance.
    stepMode | If True, two orthogonal lines are drawn for each sample as steps. This is commonly used when drawing histograms. Note that in this case, len(x) == len(y) + 1
    connect | Argument specifying how vertexes should be connected by line segments. Default is “all”, indicating full connection. “pairs” causes only even-numbered segments to be drawn. “finite” causes segments to be omitted if they are attached to nan or inf values. For any other connectivity, specify an array of boolean values.
    compositionMode | See `setCompositionMode`.

    If non-keyword arguments are used, they will be interpreted as setData(y) for a single argument and setData(x, y) for two arguments.

  `setFillLevel`(level)

    Set the level filled to when filling under the curve

  `setPen`(*args, **kargs)

    Set the pen used to draw the curve.

  `setShadowPen`(*args, **kargs)

    Set the shadow pen used to draw behind the primary pen. This pen must have a larger width than the primary pen to be visible.

  `viewTransformChanged`()

    Called whenever the transformation matrix of the view has changed. (eg, the view range has changed or the view was resized)